(this.webpackJsonpstreamlit_folium=this.webpackJsonpstreamlit_folium||[]).push([[0],{6:function(e,t,n){"use strict";n.r(t);var a=n(3),l=n(5),_=null;a.a.events.addEventListener(a.a.RENDER_EVENT,(function(e){var t=e.detail,n=t.args.fig,i=t.args.height,d=t.args.width,c=Object(l.a)(o,250);function o(){var e=__GLOBAL_DATA__,t=e.map,n=t.getBounds(),l=t.getZoom();a.a.setComponentValue({last_clicked:e.lat_lng_clicked,last_object_clicked:e.last_object_clicked,all_drawings:e.all_drawings,last_active_drawing:e.last_active_drawing,bounds:n,zoom:l})}function r(e){return s(e)}function s(e){var t=__GLOBAL_DATA__;t.last_object_clicked=e.latlng,e.layer&&e.layer.toGeoJSON&&(t.last_active_drawing=e.layer.toGeoJSON());var n=t.drawnItems.toGeoJSON().features;t.all_drawings=n,c()}if(null==_)try{_=__GLOBAL_DATA__.map}catch(A){var m=document.getElementById("map_div"),u=document.getElementById("map_div2");if(u&&(u.style.height="".concat(i,"px"),u.style.width="".concat(d,"px")),m){if(m.style.height="".concat(i,"px"),m.style.width="".concat(d,"px"),-1!==n.indexOf("document.getElementById('export')")){var g=document.createElement("a");g.href="#",g.id="export",g.innerHTML="Export",document.body.appendChild(g)}var p=document.createElement("script"),v=n+"\n          window.__GLOBAL_DATA__ = {\n            map: map_div,\n            bounds: map_div.getBounds(),\n            lat_lng_clicked: null,\n            last_object_clicked: null,\n            all_drawings: null,\n            last_active_drawing: null,\n            zoom: null,\n            drawnItems: drawnItems,\n        };";p.innerHTML=v,document.body.appendChild(p);var w=__GLOBAL_DATA__.map;for(var h in w.on("click",(function(e){__GLOBAL_DATA__.lat_lng_clicked=e.latlng,c()})),w.on("moveend",(function(e){c()})),w._layers){w._layers[h].on("click",s)}w.on("draw:created",r),w.on("draw:edited",r),w.on("draw:deleted",r),a.a.setFrameHeight(),o()}}})),a.a.setComponentReady(),a.a.setFrameHeight()}},[[6,1,2]]]);
//# sourceMappingURL=main.1f20767d.chunk.js.map